/*
 * Jalview - A Sequence Alignment Editor and Viewer
 * Copyright (C) 2006 AM Waterhouse, J Procter, G Barton, M Clamp, S Searle
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */
package jalview.commands;

import jalview.util.ShiftList;

import jalview.datamodel.*;

public class TrimRegionCommand
    extends EditCommand
{
  public static String TRIM_LEFT = "TrimLeft";
  public static String TRIM_RIGHT = "TrimRight";

  public ColumnSelection colSel = null;

  int [] start;

  public TrimRegionCommand(String description,
                     String command,
                     SequenceI[] seqs,
                     int column,
                     AlignmentI al,
                     ColumnSelection colSel)
  {
    this.description = description;
    if (command.equalsIgnoreCase(TRIM_LEFT))
    {
      edits = new Edit[] { new Edit(CUT, seqs, 0, column, al)};
      this.colSel = colSel;
    }
    else if (command.equalsIgnoreCase(TRIM_RIGHT))
    {
      edits = new Edit[]
          { new Edit(CUT, seqs, column+1, al.getWidth() - column, al)};
    }

    //We need to keep a record of the sequence start
    //in order to restore the state after a redo
    int i, isize = edits[0].seqs.length;
    start = new int[isize];
    for(i=0; i<isize; i++)
      start[i] = edits[0].seqs[i].getStart();

    performEdit(0);
  }

  void cut(Edit command)
  {
    int column, j, jSize = command.seqs.length;
    for (j = 0; j < jSize; j++)
    {
      if(command.position==0)
      {
        column = command.seqs[j].findPosition(command.number);
        command.seqs[j].setStart(column);
      }
      else
      {
        column = command.seqs[j].findPosition(command.position)-1;
        command.seqs[j].setEnd(column);
      }
    }
    super.cut(command);
  }

  void paste(Edit command)
  {
    super.paste(command);
    int column, j, jSize = command.seqs.length;
    for (j = 0; j < jSize; j++)
    {
      if(command.position==0)
      {
        command.seqs[j].setStart(start[j]);
      }
      else
      {
        column = command.seqs[j]
            .findPosition(command.number+command.position)-1;
        command.seqs[j].setEnd(column);
      }
    }

    if(command.position==0)
    {
      ShiftList slist = new ShiftList();
      slist.addShift(0, -command.number);
      colSel.compensateForEdits(slist);
    }
  }

}
